/*++

Authur: Version 3.0
	Michael Stevens
	michael@mech.eng.usyd.edu.au
Author: Versions to 2.0
	Jari Salminen
	

Module Name:

    isr.c

Abstract:

    Interrupt service routine for the Transputer B008 Motherboard device driver.

Environment:

    Kernel mode

--*/

//
// Driver ISR
//
// When we get here, we acknowledge the interrupt from the
// B008 and simply let the defered processing routine take over
// to complete the task.
//


#include <ntddk.h>
#include "B008drv.h"
#include "LinkIoctl.h"
#include "isr.h"
#include "linksup.h"


BOOLEAN
TpdISR(
    IN    PKINTERRUPT pInterrupt,
    IN    PVOID Context
)
/*++

Routine Description:

    Interrupt service routine for the B008 card.

Arguments:

    pInterrupt - our interrupt
    Contest - Pointer to our device extension info


Return Value:

    TRUE if we handled the interrupt

--*/
{
    PDEVICE_INFO pDI = (PDEVICE_INFO)Context;
    BOOLEAN Result = FALSE;		// Assume interrupt not handled until we find its source

	PUCHAR	C012_osr = pDI->PortBase + OFFSET_OSR;

	// Make sure all our device info is reasonable
    ASSERT(pDI->DeviceType == LINK_TYPE);

	// Must have a CurrentIrp else definately bogus, ASSERT when debugging
	ASSERT (pDI->pDeviceObject->CurrentIrp != NULL);

	if (pDI->pDeviceObject->CurrentIrp != NULL) {

    	// See who the interrupt is for and request the
	    // appropriate deferred routine
	    //

		// An output ready interrupt?
		if ( (READ_PORT_UCHAR( C012_osr ) & (C012_OSR_READY|C012_OSR_IENABLE))
				== (C012_OSR_READY|C012_OSR_IENABLE) )
		{
			// Clear the interrupt by temp disabling the source
			WRITE_PORT_UCHAR( C012_osr, 0 );
			ASSERT( (READ_PORT_UCHAR( C012_osr ) & (C012_OSR_READY|C012_OSR_IENABLE))
				== C012_OSR_READY );

			IoRequestDpc( pDI->pDeviceObject, pDI->pDeviceObject->CurrentIrp, NULL );
		    Result = TRUE;
		}// Output Interrupt
		
	}// Have and Irp
	

    // Record bogus interupts
	if (!Result) {
        pDI->nBogusInterrupts++;
	}

    return Result;
}

