/*
 * LinkIoctl.h    IO control codes
 *
 * Codes are chosen to be compatible with those used by IMP Aachen
 */


#ifndef _LINKIOCTL_H
#define _LINKIOCTL_H

/* Device type           -- Random Number in NT's "User Defined" range */
#define LINK_TYPE 40000UL

/* The ioctl function codes from 0x800 through 0xFFF are reserved for
 * customer use. The ioctl code definition contains the device type,
 * a command identifier, the type of access with which the file must
 * have been opened, and the type of buffering.
 * We use codes 0x800 through 0xEFF for general purpose common to all
 * link interfaces. A driver is free not to support certain codes,
 * but it may not use those codes with different meanings.
 * Codes 0xF00 through 0xFEF may be used for special purposes. That
 * means that programs using those codes are very likely to run only
 * with one driver!
 * Codes 0xFF0 through 0xFFF are for debugging.
 */


#define IOCTL_LINK_RESET_INTERFACE \
  CTL_CODE(LINK_TYPE, 0x800, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_RESET_LINK \
  CTL_CODE(LINK_TYPE, 0x801, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_ANALYSE_LINK \
  CTL_CODE(LINK_TYPE, 0x802, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_TEST_READ \
  CTL_CODE(LINK_TYPE, 0x803, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_TEST_WRITE \
  CTL_CODE(LINK_TYPE, 0x804, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_TEST_ERROR \
  CTL_CODE(LINK_TYPE, 0x805, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_SET_SPEED \
  CTL_CODE(LINK_TYPE, 0x806, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_GET_SPEED \
  CTL_CODE(LINK_TYPE, 0x807, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_ENABLE_DMA \
  CTL_CODE(LINK_TYPE, 0x808, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_DISABLE_DMA \
  CTL_CODE(LINK_TYPE, 0x809, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_TEST_DMA \
  CTL_CODE(LINK_TYPE, 0x80A, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_GET_INFO \
  CTL_CODE(LINK_TYPE, 0x80B, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_SET_TIMEOUT \
  CTL_CODE(LINK_TYPE, 0x80C, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_GET_TIMEOUT \
  CTL_CODE(LINK_TYPE, 0x80D, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_ENABLE_HEADER_MODE \
  CTL_CODE(LINK_TYPE, 0x80E, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_DISABLE_HEADER_MODE \
  CTL_CODE(LINK_TYPE, 0x80F, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_LINK_TEST_HEADER_MODE \
  CTL_CODE(LINK_TYPE, 0x810, METHOD_BUFFERED, FILE_ANY_ACCESS)

/* This ioctl code is used only for debugging. */
#define IOCTL_LINK_GET_DEBUGBUFFER \
  CTL_CODE(LINK_TYPE, 0xfff, METHOD_BUFFERED, FILE_ANY_ACCESS)



#endif	// _LINKIOCTL_H

