/*++

Authur: Version 1.1
	Michael Stevens
	michael@mech.eng.usyd.edu.au
Previous Author: Versions to 2.0
	Jari Salminen


Module Name:

    B008link.c

Abstract:

	Link functions for Transputer B008 Motherboard device driver.
	Functions simplify complex sequenced operations. No state is maintain
	and simple port operations should be performed directly.

Environment:

    Kernel mode

--*/

#include <ntddk.h>
#include "linksup.h"


// Local course Sleep()  function
static void Sleep (LONG nMilliSeconds)
{
	LARGE_INTEGER liDelay;

	liDelay = LiNMul( -nMilliSeconds, 10000L );
	KeDelayExecutionThread( KernelMode, FALSE, &liDelay );
}


/*++
Routine Description:
    Reset given B008 board.

Arguments:
	nPort		- I/O port OFFSET_ address
SUCCEEDED	- board is reset
--*/

void B008ResetLink( PUCHAR nPort )
{
	PUCHAR	C012_analyse = nPort + OFFSET_ANALYSE;
	PUCHAR	C012_reset = nPort + OFFSET_RESETERROR;

	WRITE_PORT_UCHAR( C012_analyse, 0 );	/* deassert analyse  */
	WRITE_PORT_UCHAR( C012_reset, 1 );		/* assert reset      */
	Sleep( 120 );
	WRITE_PORT_UCHAR( C012_reset, 0 );		/* deassert reset    */
	Sleep( 120 );
}


/*++
Routine Description:
    Analyse given B008 board.

Arguments:
	nPort		- I/O port OFFSET_ address
--*/

void B008AnalyseLink( PUCHAR nPort )
{
	PUCHAR	C012_analyse = nPort + OFFSET_ANALYSE;
	PUCHAR	C012_reset = nPort + OFFSET_RESETERROR;

	WRITE_PORT_UCHAR( C012_reset, 0 );		/* deassert reset    */
	WRITE_PORT_UCHAR( C012_analyse, 1 );	/* assert analyse    */
	Sleep( 120 );
	WRITE_PORT_UCHAR( C012_reset, 1 );		/* assert reset      */
	Sleep( 120 );
	WRITE_PORT_UCHAR( C012_reset, 0 );		/* deassert reset    */
	Sleep( 120 );
	WRITE_PORT_UCHAR( C012_analyse, 0 );	/* deassert analyse  */
	Sleep( 120 );
}


/*++
Routine Description:
    Test if error flag is set in given B008 board.

Arguments:
	nPort		- I/O port OFFSET_ address

Return Value:
	0	- no error flag
	1	- error flag is on
--*/

ULONG B008TestError( PUCHAR nPort )
{
	PUCHAR	C012_error = nPort + OFFSET_RESETERROR;

	if ( READ_PORT_UCHAR( C012_error ) & BUS_RESETERROR_STATUS )
		return 0;
	else
		return 1;
}


/*++
Routine Description:
    Test how bytes are in the B008 input buffer

Arguments:
	nPort		- I/O port OFFSET_ address

Return Value:
	0	- idr empty
	1	- idr present
--*/

ULONG B008TestRead( PUCHAR nPort )
{
	PUCHAR	C012_isr = nPort + OFFSET_ISR;

	if ( READ_PORT_UCHAR( C012_isr ) & C012_ISR_PRESENT )
		return 1;
	else
		return 0;
}


/*++
Routine Description:
    Test how bytes are in the B008 output buffer

Arguments:
	nPort		- I/O port OFFSET_ address

Return Value:
	0	- odr empty
	1	- odr full
--*/

ULONG B008TestWrite( PUCHAR nPort )
{
	PUCHAR	C012_osr = nPort + OFFSET_OSR;

	if ( READ_PORT_UCHAR( C012_osr ) & C012_OSR_READY )
		return 1;
	else
		return 0;
}

